@@ -1,6 +1,6 @@
 package School::Code::Compare::Out;
 # ABSTRACT: organize the output to different formats
-$School::Code::Compare::Out::VERSION = '0.007';
+$School::Code::Compare::Out::VERSION = '0.101';
 use strict;
 use warnings;
 
@@ -14,8 +14,11 @@ sub new {
                     name   => time(),
                     format => 'tab',
                     lines  => [],
-                    title  => 'Comparion',
+                    title  => 'Comparison',
                     description => 'a list of files',
+                    signature => "$0 " . time(),
+                    endreport => 'End of report',
+                    link      => 'unknown',
                };
     bless $self, $class;
 
@@ -62,6 +65,30 @@ sub set_description {
     return $self;
 }
 
+sub set_signature {
+    my $self = shift;
+
+    $self->{signature} = shift;
+
+    return $self;
+}
+
+sub set_endreport {
+    my $self = shift;
+
+    $self->{endreport} = shift;
+
+    return $self;
+}
+
+sub set_link {
+    my $self = shift;
+
+    $self->{link} = shift;
+
+    return $self;
+}
+
 sub write {
     my $self        = shift;
 
@@ -70,6 +97,9 @@ sub write {
     my $filename    =   $self->{name};
     my $title       =   $self->{title};
     my $description =   $self->{description};
+    my $signature   =   $self->{signature};
+    my $endreport   =   $self->{endreport};
+    my $link        =   $self->{link};
 
     my $tt     = Template->new( ABSOLUTE => 1 );
     my $tt_dir = School::Code::Compare::Out::Template::Path->get();
@@ -77,7 +107,7 @@ sub write {
     # sort by ratio, but make sure undef values are "big" (meaning, bottom/last)
     my @result_sorted = sort { return  1 if (not defined $a->{ratio});
                                return -1 if (not defined $b->{ratio});
-                               return $a->{ratio} <=> $b->{ratio};
+                               return $b->{ratio} <=> $a->{ratio};
                              } @result;
     
     # we render all rows, appending it to one string
@@ -87,6 +117,8 @@ sub write {
         my $vars = {
             ratio        => $comparison->{ratio},
             distance     => $comparison->{distance},
+            length1      => $comparison->{length1},
+            length2      => $comparison->{length2},
             delta_length => $comparison->{delta_length},
             suspicious   => $comparison->{suspicious},
             file1        => $comparison->{file1},
@@ -97,13 +129,16 @@ sub write {
         $tt->process("$tt_dir/$format.tt", $vars, \$rendered_data_rows)
             || die $tt->error(), "\n";
     }
-    
+
     # render again, this time merging the rendered rows into the wrapping body
     $tt->process(   "$tt_dir/Body$format.tt",
                     {
                       data        => $rendered_data_rows,
                       title       => $title,
-                      description => $description
+                      description => $description,
+                      signature   => $signature,
+                      endreport   => $endreport,
+                      link        => $link,
                     },
                     $filename
                 )   || die $tt->error(), "\n";
@@ -124,7 +159,7 @@ School::Code::Compare::Out - organize the output to different formats
 
 =head1 VERSION
 
-version 0.007
+version 0.101
 
 =head1 AUTHOR
 
